Plots F_hat(z) - z where F_hat is the empirical CDF of the (normalized) ranks and z is the Uniform(0,1) CDF. The shaded band is the simultaneous (1 - gamma) envelope for F_hat(z) - z.
plot_sbc_ecdf(ranks, layout = NA, add_stats = TRUE, main = NULL, K = 500)No returns
A list of named dataframes of the rank statistic (raw or normalized)
Optional. A numeric vector specifying the layout using par(mfrow = layout)
Boolean. Should coverage, bias and precision be included in the figure.
Optional. A character specifying plot title.
Optional. Effective sample size of the MCMC that produced the ranks.