When an emc object is loaded from disk, or returned by forked processes, the pointers to custom kernels need to be re-created. This is a convenience function to do this.
fix_custom_kernel_pointers(emc, pointer_source)An emc object with the custom pointers re-instated.
A target emc object with missing pointers
Either a trend object with correct pointers or another emc object with correct pointers