Draws a probabilistic graphical model (PGM) using circles, squares, arrows, and plates for the standard EMC hierarchical model.
Draws a probabilistic graphical model (PGM) using circles, squares, arrows, and plates for the standard EMC hierarchical model.