Learn R Programming

EMC2 (version 3.5.0)

graphical_model: Graphical Model

Description

Draws a probabilistic graphical model (PGM) using circles, squares, arrows, and plates for the standard EMC hierarchical model.

Usage

graphical_model(emc)

Value

Invisibly returns a DiagrammeR grViz graph object

Arguments

emc

an emc object of type standard, blocked, or diagonal