powered by
Draws a probabilistic graphical model (PGM) using circles, squares, arrows, and plates for the standard EMC hierarchical model.
graphical_model(emc)
Invisibly returns a DiagrammeR grViz graph object
grViz
an emc object of type standard, blocked, or diagonal
standard
blocked
diagonal