Learn R Programming

EMC2 (version 3.5.0)

multinomial_logit: Multinomial Logit Response Model

Description

Unordered choice among response alternatives using a softmax over latent utilities.

Usage

multinomial_logit()

Arguments

Value

A model list with all the necessary functions to sample

Details

Model parameters are: utility (unbounded).

Examples

Run this code
dmnl <- design(
  Rlevels = c("left", "right"),
  factors = list(subjects = 1, S = c("left", "right")),
  formula = list(utility ~ 0 + S),
  matchfun = function(d) d$S == d$lR,
  model = multinomial_logit
)

Run the code above in your browser using DataLab