Learn R Programming

EMC2 (version 3.5.0)

multinomial_probit: Multinomial Probit Response Model

Description

Unordered choice among response alternatives using latent Gaussian utility noise. Assumes independent Gaussian shocks across alternatives, which implies correlated pairwise differences in the implied comparison space.

Usage

multinomial_probit()

Arguments

Value

A model list with all the necessary functions to sample

Details

Model parameters are: utility (unbounded).

Examples

Run this code
dmnp <- design(
  Rlevels = c("left", "right"),
  factors = list(subjects = 1, S = c("left", "right")),
  formula = list(utility ~ 0 + S),
  matchfun = function(d) d$S == d$lR,
  model = multinomial_probit
)

Run the code above in your browser using DataLab