Learn R Programming

EMC2 (version 3.5.0)

ordered_logit: Ordered Logit Response Model

Description

Ordered responses based on a latent logistic evidence variable. Binary response models are the 2-category special case.

Usage

ordered_logit()

Arguments

Value

A model list with all the necessary functions to sample

Details

The scale parameter is the latent logistic scale, and thresholds follow the same ordered K - 1 parameterization as ordered_probit(), with derived ordered thresholds returned in cut_expanded.

Examples

Run this code
dord <- design(
  Rlevels = c("left", "right"),
  factors = list(subjects = 1, S = c("left", "right")),
  formula = list(location ~ 0 + S, scale ~ 1, cut ~ 1),
  matchfun = function(d) d$S == d$lR,
  constants = c(scale = log(1)),
  model = ordered_logit
)

Run the code above in your browser using DataLab